@@ -3,10 +3,10 @@ package Data::Path;
 use 5.006001;
 use strict;
 use warnings;
-use Scalar::Util qw/reftype blessed/;
+use Scalar::Util 'blessed';
 use Carp;
 
-our $VERSION = '1.4.1';
+our $VERSION = '1.1';
 
 sub new {
 	my ($class,$data,$callback)=@_;
@@ -58,11 +58,7 @@ sub get {
 
 	# get key till / or [
 	my $key = $1 if ( $rkey =~ s/^\/([^\/|\[]+)//o );
-    croak 'malformed path expression'
-        unless $key;
-   
-    croak 'malformed array index request' 
-        if $rkey =~ /^\[([^\d]*)\]/;
+	
 	# check index for index
 	my $index = $1 if ( $rkey =~ s/^\[(\d+)\]//o );
 
@@ -92,7 +88,7 @@ sub get {
 		$self->{callback}->{index_does_not_exist}->($data, $key, $index, $value, $rest) 
 			if not exists $value->[$index] and $rest;
 
-		if ( reftype $value eq 'ARRAY' ) {
+		if ( ref $value eq 'ARRAY' ) {
 			$value=$value->[$index];
 		} else {
 			$self->{callback}->{retrieve_index_from_non_array}->($data, $key, $index, $value, $rest);
@@ -101,7 +97,7 @@ sub get {
 
 	# check if last element is reached
 	if ($rest) {
-		if ( reftype $value eq 'HASH' || blessed $value ) {
+		if ( ref $value eq 'HASH' ) {
 			$value=$self->get($rest,$value);
 		} else {
 			$self->{callback}->{retrieve_key_from_non_hash}->($data, $key, $index, $value, $rest);
